\name{multcomp}
\alias{multcomp}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
Multiple comparison tests
}
\description{
Produces p-values of Bonferroni and Scheffe multiple comparison tests of several testable linear hypotheses.
}
\usage{
multcomp(y, X, A, xi, tol=sqrt(.Machine$double.eps))
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{y}{
Responese vector in linear model.
}
  \item{X}{
Design/model matrix or matrix containing values of explanatory variables (generally including intercept).
}
  \item{A}{
Coefficient matrix (A.beta=xi is the set of multiple hypotheses that has to be tested).
}
  \item{xi}{
A vector of values (A.beta=xi is the set of multiple hypotheses that has to be tested).
}
 \item{tol}{
A relative tolerance to detect zero singular values while computing generalized inverse, in case X is rank deficient (default = sqrt(.Machine$double.eps)).
 }
}

\details{
Normal distribution of response (given explanatory variables and/or factors) is assumed.
}

\value{
Returns F statistics and p-values of Bonferroni and Scheffe multiple comparison tests of the set of linear hypotheses.
A set of five vectors:
\item{A}{Specified coefficient matrix.}
\item{xi}{Specified values of A.beta.}
\item{Fstat}{Set of F-ratios for each hypothesis.}
\item{Bonferroni.p}{Set of Bonferroni p-values for different hypotheses.}
\item{Scheffe.p}{Set of Scheffe p-values for different hypotheses.}
}
\references{
Sengupta and Jammalamadaka (2019), Linear Models and Regression with R: An Integrated Approach.
}
\author{
Debasis Sengupta <shairiksengupta@gmail.com>, Jinwen Qiu <qjwsnow_ctw@hotmail.com>
}


\examples{
data(denim)
attach(denim)
X <- cbind(1,binaries(Denim),binaries(Laundry))
A <- rbind(c(0,1,-1,0,0,0,0),c(0,1,0,-1,0,0,0),c(0,0,1,-1,0,0,0))
xi <- c(0,0,0)
multcomp(Abrasion, X, A, xi, tol=1e-14)
detach(denim)
}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ htest }
\keyword{ model }
\keyword{ design }
\keyword{ regression }
